pub unsafe fn transport_mut(ptr: *mut u8) -> &'static mut TransportStateExpand description
Returns a mutable reference to the transport state.
Safety
ptr must point to a valid allocation containing at least TransportState’s size.
pub unsafe fn transport_mut(ptr: *mut u8) -> &'static mut TransportStateReturns a mutable reference to the transport state.
ptr must point to a valid allocation containing at least TransportState’s size.