pub unsafe fn transport_ref(ptr: *mut u8) -> &'static TransportStateExpand description
Returns a reference to the transport state.
Safety
ptr must point to a valid allocation containing at least TransportState’s size.
pub unsafe fn transport_ref(ptr: *mut u8) -> &'static TransportStateReturns a reference to the transport state.
ptr must point to a valid allocation containing at least TransportState’s size.